/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2006 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ServerProxyMBean.java 9871 2006-11-27 09:55:29 +0000 (Mon, 27 Nov 2006) danesa $
 * --------------------------------------------------------------------------
 */
package org.objectweb.jonas.management.monitoring;

import javax.management.MBeanServer;


/**
 * Implements MBean interface for proxy MBeans. A proxy MBean represents a server in
 * the domain on the master server's MBean server.
 * @author Adriana Danes
 */
public interface ServerProxyMBean {

    /**
     * @return maximum number of retries when detecting a broken connection
     */
    int getMaxcheck();

    /**
     * @param maxcheck value for maximum number of retries when detecting a broken connection
     */
    void setMaxcheck(int maxcheck);

    /**
     * Set state to RUNNING
     */
    void startit();
    /**
     * Stop server
     */
    void stopit();

    String deployModule(String filename);
    String undeployModule(String filename);
    void uploadFile(String filename, boolean replaceExisting);
    void uploadDeployModule(String filename, boolean replaceExisting);

    String getClusterDaemonName();

    int getAllThreadsCount();

    int getBusyMaxJCAConnection();

    int getBusyMinJCAConnection();

    public long getBytesReceivedByConnectorTomcat();

    public long getBytesSentByConnectorTomcat();

    int getConnectionFailuresJCAConnection();

    int getConnectionLeaksJCAConnection();

    int getCurrentBusyJCAConnection();

    int getCurrentInTxJCAConnection();

    int getCurrentNumberOfBMP();

    int getCurrentNumberOfCMP();

    int getCurrentNumberOfEBInMemory();

    int getCurrentNumberOfEJB();

    int getCurrentNumberOfMDB();

    int getCurrentNumberOfSBF();

    int getCurrentNumberOfSBFInMemory();

    int getCurrentNumberOfSBL();

    int getCurrentNumberOfSBLInMemory();

    int getCurrentOpenedJCAConnection();

    int getCurrentThreadBusyByConnectorTomcat();

    int getCurrentThreadCountByConnectorTomcat();

    Long getCurrentTotalMemory();

    Long getCurrentUsedMemory();

    int getCurrentWaitersJCAConnection();

    int getCurrentWorkerPoolSize();

    int getErrorCountByConnectorTomcat();

    String getHostName();

    int getInitPoolSizeJCAConnection();

    String getJavaVendor();

    String getJavaVersion();

    int getJmsQueuesNbMsgsDeliverSinceCreation();

    int getJmsQueuesNbMsgsReceiveSinceCreation();

    int getJmsQueuesNbMsgsSendToDMQSinceCreation();

    int getJmsTopicsNbMsgsDeliverSinceCreation();

    int getJmsTopicsNbMsgsReceiveSinceCreation();

    int getJmsTopicsNbMsgsSendToDMQSinceCreation();

    String getJOnASVersion();

    String getLoadCPU();

    int getMaxNumberOfEBInMemory();

    int getMaxNumberOfSBFInMemory();

    int getMaxNumberOfSBLInMemory();

    int getMaxThreadsByConnectorTomcat();

    int getMaxWorkerPoolSize();

    public MBeanServer getMbeanServer();

    int getMinPoolSizeEB();

    int getMinPoolSizeSBF();

    int getMinPoolSizeSBL();

    int getMinWorkerPoolSize();

    int getPhysicalConnectionOpenedCountJCAConnection();

    int getPoolMaxOpentimeJCAConnection();

    int getPoolMaxSizeJCAConnection();

    int getPoolMaxWaitersJCAConnection();

    int getPoolMaxWaitTimeJCAConnection();

    int getPoolMinSizeJCAConnection();

    int getPoolSizeEB();

    int getPoolSizeSBF();

    int getPoolSizeSBL();

    public long getProcessingTimeByConnectorTomcat();

    String getProtocols();

    int getPstmtMaxJCAConnection();

    int getRejectedFullJCAConnection();

    int getRejectedOpenJCAConnection();

    int getRejectedOtherJCAConnection();

    int getRejectedTimeoutJCAConnection();

    int getRequestCountByConnectorTomcat();

    /**
     * @return the server's state as known by the proxy
     */
    String getState();

    int getTotalBegunTransactions();

    int getTotalCommittedTransactions();

    int getTotalCurrentTransactions();

    int getTotalExpiredTransactions();

    int getTotalRolledbackTransactions();

    int getWaiterCountJCAConnection();

    int getWaitersHighJCAConnection();

    int getWaitersHighRecentJCAConnection();

    int getWaitingHighJCAConnection();

    int getWaitingHighRecentJCAConnection();

    int getWaitingTimeJCAConnection();

    int getXaServedOpenJCAConnection();

    String getObjectName();

    String getConnectionUrl();
}